@@ -2,25 +2,16 @@ module Cucumber
   module Core
     module Ast
       module Names
-        attr_reader :description
-
-        def name
-          title
-        end
-
-        def title
-          warn("deprecated. Use #name")
-          @title
-        end
+        attr_reader :description, :name
 
         def legacy_conflated_name_and_description
-          s = @title
+          s = name
           s += "\n#{@description}" if @description != ""
           s
         end
 
         def to_s
-          @title
+          name
         end
 
         def inspect
