@@ -1,6 +1,5 @@
 require 'cucumber/core/ast/names'
 require 'cucumber/core/ast/location'
-require 'cucumber/core/ast/empty_background'
 require 'cucumber/core/ast/describes_itself'
 
 module Cucumber
@@ -13,25 +12,19 @@ module Cucumber
 
         MissingExamples = Class.new(StandardError)
 
-        attr_reader :gherkin_statement, :language, :background, :comments,
-                    :tags, :feature_tags, :keyword, :title, :description,
+        attr_reader :comments, :tags, :keyword,
                     :steps, :examples_tables, :line
-        private :language, :background, :comments, :feature_tags,
-                :line
+        private :line
 
-        def initialize(gherkin_statement, language, location, background, comments, tags, feature_tags, keyword, title, description, steps, examples_tables)
-          @gherkin_statement = gherkin_statement
-          @language          = language
+        def initialize(location, comments, tags, keyword, name, description, steps, examples)
           @location          = location
-          @background        = background
           @comments          = comments
           @tags              = tags
-          @feature_tags      = feature_tags
           @keyword           = keyword
-          @title             = title
+          @name              = name
           @description       = description
           @steps             = steps
-          @examples_tables   = examples_tables
+          @examples_tables   = examples
         end
 
         private
