@@ -7,7 +7,7 @@ module Cucumber
       class Step
         attr_reader :source
 
-        def initialize(source, action = Test::UndefinedAction.new)
+        def initialize(source, action = Test::UndefinedAction.new(source.last.location))
           raise ArgumentError if source.any?(&:nil?)
           @source, @action = source, action
         end
@@ -31,8 +31,8 @@ module Cucumber
           @action.execute(*args)
         end
 
-        def with_action(&block)
-          self.class.new(source, Test::Action.new(&block))
+        def with_action(location = nil, &block)
+          self.class.new(source, Test::Action.new(location, &block))
         end
 
         def name
@@ -43,9 +43,8 @@ module Cucumber
           source.last.location
         end
 
-        def match_locations?(queried_locations)
-          return true if queried_locations.include? location
-          source.any? { |s| s.match_locations?(queried_locations) }
+        def action_location
+          @action.location
         end
 
         def inspect
@@ -53,6 +52,25 @@ module Cucumber
         end
 
       end
+
+      class IsStepVisitor
+        def initialize(test_step)
+          @is_step = false
+          test_step.describe_to(self)
+        end
+
+        def step?
+          @is_step
+        end
+
+        def test_step(*)
+          @is_step = true
+        end
+
+        def method_missing(*)
+          self
+        end
+      end
     end
   end
 end
